==> haskell-stm-hamt-1.2.0.14-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-hamt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stm-hamt
version:              1.2.0.14
visibility:           public
id:                   stm-hamt-1.2.0.14-5mXie17eG6IJvvUiRYX6Oc
key:                  stm-hamt-1.2.0.14-5mXie17eG6IJvvUiRYX6Oc
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/stm-hamt
synopsis:             STM-specialised Hash Array Mapped Trie
description:
    A low-level data-structure,
    which can be used to implement higher-level interfaces like
    hash-map and hash-set.
    Such implementations are presented by the
    <http://hackage.haskell.org/package/stm-containers stm-containers>.

category:             Data Structures, STM, Concurrency
abi:                  f50f30ec6450f1bdab9c7f4c12be4674
exposed:              True
exposed-modules:      StmHamt.Hamt StmHamt.SizedHamt
hidden-modules:
    StmHamt.Constructors.Branch StmHamt.Focuses StmHamt.IntOps
    StmHamt.ListT StmHamt.Prelude StmHamt.Types StmHamt.UnfoldlM

import-dirs:          /usr/lib/ghc-9.2.8/site-local/stm-hamt-1.2.0.14
library-dirs:         /usr/lib/ghc-9.2.8/site-local/stm-hamt-1.2.0.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-hamt
hs-libraries:         HSstm-hamt-1.2.0.14-5mXie17eG6IJvvUiRYX6Oc
depends:
    base-4.16.4.0 deferred-folds-0.9.18.6-1rqky4GibVp2JEiBrPZfzR
    focus-1.0.3.2-9JTxZHxOb4j1brEHTBJ0LP
    hashable-1.4.3.0-3dqA7o3S1KBIuEdO2YDkYf
    list-t-1.0.5.4-62hRrI58rfCHfRQASqaHPI
    primitive-0.7.4.0-5Nr7R1OcK3bE67TSpaATMA
    primitive-extras-0.10.1.10-DHnGg9fW5NkDnzF31waTOP
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-stm-hamt/html/stm-hamt.haddock
haddock-html:         /usr/share/doc/haskell-stm-hamt/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stm-hamt-1.2.0.14-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-hamt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stm-hamt
version:              1.2.0.14
visibility:           public
id:                   stm-hamt-1.2.0.14-FqTLr0L6c2MJbU5VT52psh
key:                  stm-hamt-1.2.0.14-FqTLr0L6c2MJbU5VT52psh
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/stm-hamt
synopsis:             STM-specialised Hash Array Mapped Trie
description:
    A low-level data-structure,
    which can be used to implement higher-level interfaces like
    hash-map and hash-set.
    Such implementations are presented by the
    <http://hackage.haskell.org/package/stm-containers stm-containers>.

category:             Data Structures, STM, Concurrency
abi:                  40f9f7e14332c516aa6d905061c7f054
exposed:              True
exposed-modules:      StmHamt.Hamt StmHamt.SizedHamt
hidden-modules:
    StmHamt.Constructors.Branch StmHamt.Focuses StmHamt.IntOps
    StmHamt.ListT StmHamt.Prelude StmHamt.Types StmHamt.UnfoldlM

import-dirs:          /usr/lib/ghc-9.2.8/site-local/stm-hamt-1.2.0.14
library-dirs:         /usr/lib/ghc-9.2.8/site-local/stm-hamt-1.2.0.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-hamt
hs-libraries:         HSstm-hamt-1.2.0.14-FqTLr0L6c2MJbU5VT52psh
depends:
    base-4.16.4.0 deferred-folds-0.9.18.6-C805rFtgjYXAfXNl0fIhtH
    focus-1.0.3.2-73H8YW2zg8pCuY7fiBO0Af
    hashable-1.4.3.0-3dqA7o3S1KBIuEdO2YDkYf
    list-t-1.0.5.4-LPLixwBZr133h6Eqq0Njhi
    primitive-0.7.4.0-5Nr7R1OcK3bE67TSpaATMA
    primitive-extras-0.10.1.10-9fdPtt2zG94XCntZo1HXK
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-stm-hamt/html/stm-hamt.haddock
haddock-html:         /usr/share/doc/haskell-stm-hamt/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
